**********
Quickstart
**********

The ``hepstats`` module includes modeling and hypothesis tests submodules. This a quick user
guide to each submodule:


.. toctree::
    :maxdepth: 1

    modeling
    hypotests
    splot

The `binder <https://mybinder.org/v2/gh/scikit-hep/hepstats/master>`_ examples are also a good way to get started.
